@@ -9,22 +9,61 @@
         <translation>Hilfe</translation>
     </message>
     <message>
-        <location filename="helpwindow.cpp" line="74"/>
+        <location filename="helpwindow.cpp" line="62"/>
         <source>QCPUFreq</source>
         <translation>QCPUFreq</translation>
     </message>
     <message>
-        <location filename="helpwindow.cpp" line="74"/>
+        <location filename="helpwindow.ui" line="44"/>
+        <location filename="helpwindow.cpp" line="62"/>
         <source>Cannot open help file!</source>
         <translation>Kann die Hilfe-Datei nicht öffnen!</translation>
     </message>
 </context>
+<context>
+    <name>LoadPreset</name>
+    <message>
+        <location filename="loadpreset.ui" line="14"/>
+        <source>Load preset</source>
+        <translation>Lade Preset</translation>
+    </message>
+    <message>
+        <location filename="loadpreset.ui" line="23"/>
+        <source>Default</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="loadpreset.ui" line="30"/>
+        <source>Ideal</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="loadpreset.ui" line="37"/>
+        <source>LV</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="loadpreset.ui" line="44"/>
+        <source>ULV</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="loadpreset.ui" line="51"/>
+        <source>XLV</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="loadpreset.ui" line="58"/>
+        <source>Custom</source>
+        <translation></translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
         <location filename="mainwindow.ui" line="14"/>
-        <location filename="mainwindow.cpp" line="187"/>
-        <location filename="mainwindow.cpp" line="379"/>
+        <location filename="mainwindow.cpp" line="218"/>
+        <location filename="mainwindow.cpp" line="435"/>
         <source>QCPUFreq</source>
         <translation>QCPUFreq</translation>
     </message>
@@ -38,8 +77,8 @@
         <location filename="mainwindow.ui" line="67"/>
         <location filename="mainwindow.ui" line="87"/>
         <location filename="mainwindow.ui" line="107"/>
-        <location filename="mainwindow.cpp" line="215"/>
-        <location filename="mainwindow.cpp" line="224"/>
+        <location filename="mainwindow.cpp" line="246"/>
+        <location filename="mainwindow.cpp" line="255"/>
         <source>Unknown</source>
         <translation>Unbekannt</translation>
     </message>
@@ -80,52 +119,67 @@
         <translation>Datei</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="375"/>
+        <location filename="mainwindow.ui" line="376"/>
         <source>About</source>
         <translation>Über</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="380"/>
+        <location filename="mainwindow.ui" line="381"/>
         <source>Help</source>
         <translation>Hilfe</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="388"/>
+        <location filename="mainwindow.ui" line="389"/>
         <source>Enable overclocking</source>
         <translation>Aktiviere Übertakten</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="393"/>
+        <location filename="mainwindow.ui" line="394"/>
         <source>Settings</source>
         <translation>Einstellungen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="401"/>
+        <location filename="mainwindow.ui" line="402"/>
         <source>Save</source>
         <translation>Speichern</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="130"/>
+        <location filename="mainwindow.ui" line="410"/>
+        <source>Load preset</source>
+        <translation>Lade Preset</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="137"/>
         <source>You need to enable overclocking in QCPUFreq&apos;s settings in order to set frequencies above 600MHz!</source>
         <translation>Um Frequenzen über 600MHz freizuschalten, müssen Sie Übertakten in den QCPUFreq Einstellungen aktivieren!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="187"/>
+        <location filename="mainwindow.cpp" line="157"/>
+        <source>Do you really want to use %1 MHz as the new maximum frequency?</source>
+        <translation>Möchten Sie wirklich %1 MHz als neue maximale CPU Geschwindigkeit einstellen?</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="218"/>
         <source>There seems to be a problem with your sudo setup!</source>
         <translation>Es liegt offenbar ein Problem bei der sudo Einrichtung vor!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="379"/>
+        <location filename="mainwindow.cpp" line="418"/>
+        <source>The preset was loaded.</source>
+        <translation>Das Preset wurde geladen.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="435"/>
         <source>Could not get information from /sys!</source>
         <translation>Konnte Informationen aus /sys nicht lesen!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="469"/>
+        <location filename="mainwindow.cpp" line="525"/>
         <source>The current frequency settings have been saved as default.</source>
         <translation>Die aktuellen Frequenzeinstellungen wurden als Standardeinstellungen gespeichert.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="507"/>
+        <location filename="mainwindow.cpp" line="565"/>
         <source>SmartReflex support is known to be unstable on some devices and may cause random reboots.</source>
         <translation>SmartReflex kann auf einigen Geräten instabil sein und zu zufälligen Neustarts führen.</translation>
     </message>
@@ -138,38 +192,43 @@
         <translation>Einstellungen</translation>
     </message>
     <message>
-        <location filename="settings.ui" line="25"/>
+        <location filename="settings.ui" line="32"/>
+        <source>Confirm frequency changes</source>
+        <translation>Änderungen bestätigen</translation>
+    </message>
+    <message>
+        <location filename="settings.ui" line="39"/>
         <source>Enable overclocking</source>
         <translation>Aktiviere Übertakten</translation>
     </message>
     <message>
-        <location filename="settings.ui" line="32"/>
+        <location filename="settings.ui" line="25"/>
         <source>Enable auto-rotation</source>
         <translation>Aktiviere automatisches Drehen</translation>
     </message>
     <message>
-        <location filename="settings.ui" line="39"/>
+        <location filename="settings.ui" line="46"/>
         <source>Load bq27x00_battery module</source>
         <translation>Lade bq27x00_battery-Modul</translation>
     </message>
     <message>
-        <location filename="settings.cpp" line="52"/>
+        <location filename="settings.cpp" line="58"/>
         <source>QCPUFreq</source>
         <translation>QCPUFreq</translation>
     </message>
     <message>
-        <location filename="settings.cpp" line="52"/>
+        <location filename="settings.cpp" line="58"/>
         <source>Could not get information from /sys!</source>
         <translation>Konnte Informationen aus /sys nicht lesen!</translation>
     </message>
     <message>
-        <location filename="settings.cpp" line="144"/>
-        <location filename="settings.cpp" line="146"/>
+        <location filename="settings.cpp" line="165"/>
+        <location filename="settings.cpp" line="167"/>
         <source>Please note that overclocking voids your warranty and may break your device! Be careful!</source>
         <translation>Bitte beachten Sie, dass Overclocking zu Garantieverlust führt und das Gerät beschädigen kann! Seien Sie vorsichtig!</translation>
     </message>
     <message>
-        <location filename="settings.cpp" line="146"/>
+        <location filename="settings.cpp" line="167"/>
         <source>Warning</source>
         <translation>Warnung</translation>
     </message>
