@@ -16,6 +16,37 @@
         <translation>无法打开帮助文件!</translation>
     </message>
 </context>
+<context>
+    <name>LoadPreset</name>
+    <message>
+        <source>Load preset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ideal</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LV</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ULV</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>XLV</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Custom</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -98,6 +129,18 @@
         <source>The current frequency settings have been saved as default.</source>
         <translation>当前的频率设定已被保存为默认值.</translation>
     </message>
+    <message>
+        <source>Load preset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do you really want to use %1 MHz as the new maximum frequency?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The preset was loaded.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Settings</name>
@@ -133,5 +176,9 @@
         <source>Warning</source>
         <translation>警告</translation>
     </message>
+    <message>
+        <source>Confirm frequency changes</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
